@@ -1,7 +1,7 @@
 /*
 **  PGPController.m
 **
-**  Copyright (c) 2001-2006
+**  Copyright (c) 2001-2006 Ludovic Marcotte, Tomio Arisaka
 **
 **  Author: Ludovic Marcotte <ludovic@Sophos.ca>
 **          Tomio Arisaka <tomio-a@max.hi-ho.ne.jp>
@@ -17,8 +17,7 @@
 **  GNU General Public License for more details.
 **
 **  You should have received a copy of the GNU General Public License
-**  along with this program; if not, write to the Free Software
-**  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+**  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
 #include "PGPController.h"
@@ -793,18 +792,21 @@ static PGPController *singleInstance = nil;
 	    {
 	      [theMessage appendString: _(@"\nWrong passphrase (or something else)")];
 	      aBOOL = NO;
+		  RELEASE(aString);
 	      break;
 	    }
 	  else if ([aString hasPrefix: @"NODATA"])
 	    {
 	      [theMessage appendString: _(@"\nNo data has been found")];
 	      aBOOL = NO;
+		  RELEASE(aString);
 	      break;
 	    }
 	  else if ([aString hasPrefix: @"SIGEXPIRED"] ||  [aString hasPrefix: @"KEYEXPIRED"])
 	    {
 	      [theMessage appendString: _(@"\nYour key is expired. You must generate a new one\nbefore trying to send again any signed or encrypted messages.")];
 	      aBOOL = NO;
+		  RELEASE(aString);
 	      break;
 	    }
 	  // We check errors for the signature
@@ -812,15 +814,16 @@ static PGPController *singleInstance = nil;
 	    {
 	      [theMessage appendString:_(@"\nThe signature has NOT been VERIFIED okay.")];
 	      aBOOL = NO;
+		  RELEASE(aString);
 	      break;
-            }
+		}
 	  else if ([aString hasPrefix: @"ERRSIG"])
 	    {
 	      [theMessage appendString:_(@"\nIt was NOT possible to CHECK the signature.\nThis may be caused by a missing public key or an unsupported algorithm.")];
 	      aBOOL = NO;
+          RELEASE(aString);
 	      break;
-	    }
-	  
+	    }	  
 	  RELEASE(aString);
 	} // if ( [[allLines objectAtIndex: i] hasCPrefix: "[GNUPG:] "] )
       else
