@@ -1,9 +1,11 @@
 /*
 **  ConsoleWindowController.m
 **
-**  Copyright (c) 2001-2007
+**  Copyright (c) 2001-2007 Ludovic Marcotte
+**  Copyright (C) 2015-2016 Riccardo Mottola
 **
 **  Author: Ludovic Marcotte <ludovic@Sophos.ca>
+**          Riccardo Mottola <rm@gnu.org>
 **
 **  This program is free software; you can redistribute it and/or modify
 **  it under the terms of the GNU General Public License as published by
@@ -15,30 +17,25 @@
 **  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 **  GNU General Public License for more details.
 **
-**  You should have received a copy of the GNU General Public License
-**  along with this program; if not, write to the Free Software
-**  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+** You should have received a copy of the GNU General Public License
+** along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include "ConsoleWindowController.h"
+#import "ConsoleWindowController.h"
 
-#include "Constants.h"
-#include "GNUMail.h"
-#include "MailWindowController.h"
-#include "MailboxManagerController.h"
-#include "Task.h"
-#include "TaskManager.h"
+#import "Constants.h"
+#import "GNUMail.h"
+#import "MailWindowController.h"
+#import "MailboxManagerController.h"
+#import "Task.h"
+#import "TaskManager.h"
 
-#ifndef MACOSX
-#include "ConsoleWindow.h"
-#endif
-
-#include <Pantomime/CWFolder.h>
-#include <Pantomime/CWIMAPFolder.h>
-#include <Pantomime/CWIMAPStore.h>
-#include <Pantomime/CWMessage.h>
-#include <Pantomime/CWTCPConnection.h>
-#include <Pantomime/CWURLName.h>
+#import <Pantomime/CWFolder.h>
+#import <Pantomime/CWIMAPFolder.h>
+#import <Pantomime/CWIMAPStore.h>
+#import <Pantomime/CWMessage.h>
+#import <Pantomime/CWTCPConnection.h>
+#import <Pantomime/CWURLName.h>
 
 //
 // NOTE: For a good descriptions on what are the available "tasks" and how
@@ -48,9 +45,7 @@
 
 static ConsoleWindowController *singleInstance = nil;
 
-#ifdef MACOSX
 static NSMutableArray *progressIndicators = nil;
-#endif
 static NSProgressIndicator *progress = nil;
 
 static NSImage *restart = nil;
@@ -80,9 +75,7 @@ static NSImage *stop = nil;
 {
   NSString *aString;
   float f, w;
-#ifdef MACOSX
   int i;
-#endif
 
   [super drawWithFrame: cellFrame  inView: controlView];
   
@@ -131,11 +124,11 @@ static NSImage *stop = nil;
       break;
       
     case SAVE_ASYNC:
-      aString = [NSString stringWithFormat: _(@"Saving message to the mailbox...")];
+      aString = _(@"Saving message to the mailbox...");
       break;
       
     case LOAD_ASYNC:
-      aString = [NSString stringWithFormat: _(@"Loading message from the mailbox...")];
+      aString = _(@"Loading message from the mailbox...");
       break;
 
     case CONNECT_ASYNC:
@@ -175,7 +168,6 @@ static NSImage *stop = nil;
   // We now draw our progress indicator
   //
   cellFrame.size.height = 12;
-#ifdef MACOSX
   cellFrame.origin.y += 18; 
   i = [[[TaskManager singleInstance] allTasks] indexOfObject: _task];
   
@@ -198,12 +190,6 @@ static NSImage *stop = nil;
     }
 
   [progress setDoubleValue: f];
-#else
-  cellFrame.origin.y += 15;
-  [progress setBounds: cellFrame];
-  [progress setDoubleValue: f];
-  [progress drawRect: cellFrame];
-#endif
      
   cellFrame.origin.x -= 1.5;
 
@@ -284,7 +270,6 @@ static NSImage *stop = nil;
 - (void) _startTask;
 - (void) _stopAnimation;
 - (void) _stopTask;
-- (IBAction) _updateAnimatedIcon: (id) sender;
 @end
 
 //
@@ -308,30 +293,8 @@ static NSImage *stop = nil;
 @implementation ConsoleWindowController
 
 - (id) initWithWindowNibName: (NSString *) windowNibName
-{
-#ifdef MACOSX
-  
+{  
   self = [super initWithWindowNibName: windowNibName];
-  
-#else
-  ConsoleWindow *aConsoleWindow;
-
-  aConsoleWindow = [[ConsoleWindow alloc] initWithContentRect: NSMakeRect(100,100,500,280)
-					  styleMask: NSTitledWindowMask|NSClosableWindowMask|NSResizableWindowMask
-					  backing: NSBackingStoreBuffered
-					  defer: NO];
-  
-  self = [super initWithWindow: aConsoleWindow];
-  
-  [aConsoleWindow layoutWindow];
-  [aConsoleWindow setDelegate: self];
-
-  // We link our outlets
-  tasksTableView = aConsoleWindow->tasksTableView;
-  messagesTableView = aConsoleWindow->messagesTableView;
- 
-  RELEASE(aConsoleWindow);
-#endif
 
   [[self window] setTitle: _(@"GNUMail Console")];
   
@@ -347,14 +310,7 @@ static NSImage *stop = nil;
   restart = RETAIN([NSImage imageNamed: @"restart_32.tiff"]);
   stop = RETAIN([NSImage imageNamed: @"stop_32.tiff"]);
 
-#ifndef MACOSX
-  progress = [[NSProgressIndicator alloc] initWithFrame: NSZeroRect];
-  [progress setIndeterminate: NO];
-  [progress setMinValue: 0];
-  [progress setMaxValue: 1.0];
-#else
   progressIndicators = [[NSMutableArray alloc] init];
-#endif
 
   // We remove the header / corner view from our tables
   [tasksTableView setHeaderView: nil];
@@ -362,8 +318,6 @@ static NSImage *stop = nil;
   [messagesTableView setHeaderView: nil];
   [messagesTableView setCornerView: nil];
 
-  animation = nil;
-
   return self;
 }
 
@@ -381,11 +335,7 @@ static NSImage *stop = nil;
   RELEASE(restart);
   RELEASE(stop);
 
-#ifndef MACOSX
-  RELEASE(progress);
-#else
   RELEASE(progressIndicators);
-#endif
 
   [super dealloc];
 }
@@ -584,11 +534,9 @@ static NSImage *stop = nil;
   [menu addItem: aMenuItem];
   RELEASE(aMenuItem);
 
-#ifdef MACOSX
   [tasksTableView setAction: @selector(clickedOnTableView:)];
   [tasksTableView reloadData];
   [messagesTableView reloadData];
-#endif
 }
 
 
@@ -697,12 +645,10 @@ static NSImage *stop = nil;
 //
 //
 //
-#ifdef MACOSX
 - (id) progressIndicators
 {
   return progressIndicators;
 }
-#endif
 
 
 //
@@ -732,21 +678,17 @@ static NSImage *stop = nil;
 - (void) reload
 {
   int count;
-#ifdef MACOSX
   int i;
-#endif
   
   [tasksTableView reloadData];
   
   count = [[[TaskManager singleInstance] allTasks] count];
 
-#ifdef MACOSX
   // Remove all unused progress indicators from table view
   for (i = count; i < [progressIndicators count]; i++)
     {
       [[progressIndicators objectAtIndex: i] removeFromSuperview];
     }
-#endif
 
   while (count--)
     {
@@ -810,31 +752,14 @@ static NSImage *stop = nil;
 
 - (void) _startAnimation
 {
-  // If our animation is already started, we do nothing.
-  if (animation == nil)
+  unsigned int count;
+      
+  count = [[GNUMail allMailWindows] count];
+  
+  while (count--)
     {
-#ifdef MACOSX
-      unsigned int count;
-      
-      count = [[GNUMail allMailWindows] count];
-	  
-      while (count--)
-	{
-	  [((MailWindowController *)[[[GNUMail allMailWindows] objectAtIndex: count] windowController])->progressIndicator startAnimation: self];
-	}
-#endif     
-      
-      animation_index = 1;
-      animation = [NSTimer timerWithTimeInterval: 0.1
-			   target: self
-			   selector: @selector(_updateAnimatedIcon:)
-			   userInfo: nil
-			   repeats: YES];
-      [[NSRunLoop currentRunLoop] addTimer: animation  forMode: NSEventTrackingRunLoopMode];
-      [[NSRunLoop currentRunLoop] addTimer: animation  forMode: NSDefaultRunLoopMode];
-      [[NSRunLoop currentRunLoop] addTimer: animation  forMode: NSModalPanelRunLoopMode];
-      RETAIN(animation);
-    }
+      [((MailWindowController *)[[[GNUMail allMailWindows] objectAtIndex: count] windowController])->progressIndicator startAnimation: self];
+    }  
 }
 
 - (void) _startTask
@@ -860,27 +785,19 @@ static NSImage *stop = nil;
 
 - (void) _stopAnimation
 {
-  if (animation != nil)
+  MailWindowController *aController;
+  unsigned int count;
+  
+  count = [[GNUMail allMailWindows] count];
+  
+  while (count--)
     {
-      MailWindowController *aController;
-      unsigned int count;
-      
-      count = [[GNUMail allMailWindows] count];
-
-      while (count--)
-	{
-	  aController = (MailWindowController *)[[[GNUMail allMailWindows] objectAtIndex: count] windowController];
-#ifdef MACOSX
-	  [aController->progressIndicator stopAnimation: self];
-#endif
-	  [aController updateStatusLabel];
-	}
-
-      [animation invalidate];
-      DESTROY(animation);
-      
-      [self restoreImage];
+      aController = (MailWindowController *)[[[GNUMail allMailWindows] objectAtIndex: count] windowController];
+      [aController->progressIndicator stopAnimation: self];
+      [aController updateStatusLabel];
     }
+  
+  [self restoreImage];
 }
 
 - (void) _stopTask
@@ -900,39 +817,6 @@ static NSImage *stop = nil;
 }
 
 
-//
-// This method does absolutely nothing under OS X
-//
-- (IBAction) _updateAnimatedIcon: (id) sender
-{
-  NSWindow *aWindow;
-  int count;
-
-#ifndef MACOSX
-  if (animation_index == 9)
-    {
-      animation_index = 1;
-    }
-
-  count = [[GNUMail allMailWindows] count];
-
-  while (count--)
-    {
-      aWindow = [[GNUMail allMailWindows] objectAtIndex: count];
-
-#ifdef MACOSX 
-      if ([[aWindow toolbar] customizationPaletteIsRunning])
-	{
-	  continue;
-	}
-#endif
-      [((MailWindowController *)[aWindow windowController])->icon setImage: [NSImage imageNamed: [NSString stringWithFormat: @"anim-logo-%d.tiff", animation_index]]];
-    }
-  
-  animation_index += 1;
-#endif
-}
-
 @end
 
 
