@@ -1,8 +1,8 @@
 /*
 **  EditWindowController.m
 **
-**  Copyright (c) 2001-2007
-**                2014
+**  Copyright (c) 2001-2007 Ludovic Marcotte
+**  Copyright (C) 2014-2015 Riccardo Mottola
 **
 **  Author: Ludovic Marcotte <ludovic@Sophos.ca>
 **          Riccardo Mottola <rm@gnu.org>
@@ -17,9 +17,8 @@
 **  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 **  GNU General Public License for more details.
 **
-**  You should have received a copy of the GNU General Public License
-**  along with this program; if not, write to the Free Software
-**  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+** You should have received a copy of the GNU General Public License
+** along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
 #include "EditWindowController.h"
@@ -27,10 +26,6 @@
 #include "AddressBookController.h"
 #include "AutoCompletingTextField.h"
 
-#ifndef MACOSX
-#include "EditWindow.h"
-#endif
-
 #include "ExtendedMenuItem.h"
 #include "ExtendedTextAttachmentCell.h"
 #include "ExtendedTextView.h"
@@ -88,7 +83,7 @@
 #define L_HEIGHT 17
 #define L_WIDTH 55
 
-#define Y_DELTA 30
+#define Y_DELTA 26
 #define W_DELTA 91
 
 #define F_X 71
@@ -98,8 +93,8 @@
 #define S_Y 0
 #else
 #define L_X 5
-#define L_HEIGHT 21
-#define L_WIDTH 50
+#define L_HEIGHT 17
+#define L_WIDTH 55
 
 #define Y_DELTA 25
 #define W_DELTA 75
@@ -107,8 +102,8 @@
 #define F_X 65
 #define F_HEIGHT 21
 
-#define S_X 5
-#define S_Y 5
+#define S_X 0
+#define S_Y 0
 #endif
 
 //
@@ -177,10 +172,6 @@
 {  
   NSDictionary *allAccounts;
   NSToolbar *aToolbar;
-
-#ifndef MACOSX
-  EditWindow *theEditWindow;
-#endif
   
   allAccounts = [Utilities allEnabledAccounts];
 
@@ -199,37 +190,7 @@
 
 
 
-#ifdef MACOSX
   self = [super initWithWindowNibName: windowNibName];
-#else
-  theEditWindow = [[EditWindow alloc] initWithContentRect: NSMakeRect(50,75,750,520)
-				      styleMask: (NSClosableWindowMask|NSTitledWindowMask|
-						  NSMiniaturizableWindowMask|NSResizableWindowMask)
-				      backing: NSBackingStoreRetained
-				      defer: NO];
-  
-  self = [super initWithWindow: theEditWindow];
-  [theEditWindow layoutWindow];
-  [theEditWindow setDelegate: self];
-  
-  // We link our outlets
-  subjectText = theEditWindow->subjectText;
-  toText = theEditWindow->toText;
-  ccText = theEditWindow->ccText;
-  bccText = theEditWindow->bccText;
-  subjectLabel = theEditWindow->subjectLabel;
-  toLabel = theEditWindow->toLabel;
-  ccLabel = theEditWindow->ccLabel;
-  bccLabel = theEditWindow->bccLabel;
-  sizeLabel = theEditWindow->sizeLabel;
-  scrollView = theEditWindow->scrollView;
-  textView = theEditWindow->textView;
-  accountPopUpButton = theEditWindow->accountPopUpButton;
-  //transportMethodPopUpButton = theEditWindow->transportMethodPopUpButton;
-
-  RELEASE(theEditWindow);
-#endif
-
   
   //
   // We create our mutable array and our mutable dictionary allowing
@@ -263,10 +224,8 @@
   [[self window] setToolbar: aToolbar];
   RELEASE(aToolbar);
   
-#ifdef MACOSX
   RETAIN(ccLabel); RETAIN(ccText);
   RETAIN(bccLabel); RETAIN(bccText);
-#endif
 
   // We initialize our variables
   [self setShowCc: NO];
@@ -369,13 +328,11 @@
 {
   NSDebugLog(@"EditWindowController: -dealloc");
   
-  [[self window] setDelegate: nil]; // FIXME not necessary in coca and in gnustep as of 2014-02-11, only for compatibility with old releases
+  [[self window] setDelegate: nil]; // FIXME not necessary in cocoa and in gnustep as of 2014-02-11, only for compatibility with old releases
   [[NSNotificationCenter defaultCenter] removeObserver: self];
 
-#ifdef MACOSX
   RELEASE(ccLabel); RELEASE(ccText);
   RELEASE(bccLabel); RELEASE(bccText);
-#endif
 
   TEST_RELEASE(message);
   TEST_RELEASE(unmodifiedMessage);
@@ -935,10 +892,6 @@
 //
 - (void) windowDidBecomeMain: (NSNotification *) theNotification
 {
-#ifndef MACOSX
-  [[[self window] contentView] setNeedsDisplay: YES];
-#endif
-
   [GNUMail setLastAddressTakerWindowOnTop: self];
 }
 
@@ -1829,10 +1782,8 @@
   float size;
 
   pool = [[NSAutoreleasePool alloc] init];
-
-  size = [[textView string] length];
+  size = (float)[[textView string] length];
   size = (float)(size / (float)1024);
-
   aTextStorage = [textView textStorage];
   
   // FIXME
@@ -2653,7 +2604,7 @@
     {
       NSTextStorage *aTextStorage;
       float size;
-      
+
       aTextStorage = [textView textStorage];
       size = [self _estimatedSizeOfMessage];
       
