@@ -1,8 +1,8 @@
 /*
 **  MailWindowController.m
 **
-**  Copyright (c) 2001-2007
-**                2014
+**  Copyright (c) 2001-2007 Ludovic Marcotte
+**  Copyright (C) 2014-2016 Riccardo Mottola
 **
 **  Author: Ludovic Marcotte <ludovic@Sophos.ca>
 **          Riccardo Mottola <rm@gnu.org>
@@ -17,67 +17,66 @@
 **  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 **  GNU General Public License for more details.
 **
-**  You should have received a copy of the GNU General Public License
-**  along with this program; if not, write to the Free Software
-**  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+** You should have received a copy of the GNU General Public License
+** along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include "MailWindowController.h"
+#import "MailWindowController.h"
 
-#include "AddressBookController.h"
-#include "ApplicationIconController.h"
-#include "ConsoleWindowController.h"
-#include "Constants.h"
-#include "EditWindowController.h"
-#include "ExtendedCell.h"
-#include "ExtendedOutlineView.h"
-#include "ExtendedTableView.h"
-#include "ExtendedWindow.h"
-#include "GNUMail.h"
-#include "GNUMailBundle.h"
-#include "LabelWidget.h"
+#import "AddressBookController.h"
+#import "ApplicationIconController.h"
+#import "ConsoleWindowController.h"
+#import "Constants.h"
+#import "EditWindowController.h"
+#import "ExtendedCell.h"
+#import "ExtendedOutlineView.h"
+#import "ExtendedTableView.h"
+#import "ExtendedWindow.h"
+#import "GNUMail.h"
+#import "GNUMailBundle.h"
+#import "LabelWidget.h"
 
 #ifndef MACOSX
-#include "MailWindow.h"
+#import "MailWindow.h"
 #endif
 
-#include "Filter.h"
-#include "FilterManager.h"
-#include "FolderNode.h"
-#include "FolderNodePopUpItem.h"
-#include "ImageTextCell.h"
-#include "MailboxManagerCache.h"
-#include "MailboxManagerController.h"
-#include "MailboxInspectorPanelController.h"
-#include "MailHeaderCell.h"
-#include "ThreadArcsCell.h"
-#include "MessageViewWindowController.h"
-#include "MimeType.h"
-#include "MimeTypeManager.h"
-#include "NSFont+Extensions.h"
-#include "NSUserDefaults+Extensions.h"
-#include "Task.h"
-#include "TaskManager.h"
-#include "Utilities.h"
+#import "Filter.h"
+#import "FilterManager.h"
+#import "FolderNode.h"
+#import "FolderNodePopUpItem.h"
+#import "ImageTextCell.h"
+#import "MailboxManagerCache.h"
+#import "MailboxManagerController.h"
+#import "MailboxInspectorPanelController.h"
+#import "MailHeaderCell.h"
+#import "ThreadArcsCell.h"
+#import "MessageViewWindowController.h"
+#import "MimeType.h"
+#import "MimeTypeManager.h"
+#import "NSFont+Extensions.h"
+#import "NSUserDefaults+Extensions.h"
+#import "Task.h"
+#import "TaskManager.h"
+#import "Utilities.h"
 
-#include <Pantomime/CWConstants.h>
-#include <Pantomime/CWContainer.h>
-#include <Pantomime/CWFlags.h>
-#include <Pantomime/CWFolder.h>
-#include <Pantomime/CWIMAPFolder.h>
-#include <Pantomime/CWIMAPStore.h>
-#include <Pantomime/CWInternetAddress.h>
-#include <Pantomime/CWLocalFolder.h>
-#include <Pantomime/CWLocalStore.h>
-#include <Pantomime/CWMessage.h>
-#include <Pantomime/CWPOP3Folder.h>
-#include <Pantomime/CWPOP3Store.h>
-#include <Pantomime/CWPOP3CacheManager.h>
-#include <Pantomime/CWTCPConnection.h>
-#include <Pantomime/CWURLName.h>
-#include <Pantomime/CWVirtualFolder.h>
-#include <Pantomime/NSData+Extensions.h>
-#include <Pantomime/NSString+Extensions.h>
+#import <Pantomime/CWConstants.h>
+#import <Pantomime/CWContainer.h>
+#import <Pantomime/CWFlags.h>
+#import <Pantomime/CWFolder.h>
+#import <Pantomime/CWIMAPFolder.h>
+#import <Pantomime/CWIMAPStore.h>
+#import <Pantomime/CWInternetAddress.h>
+#import <Pantomime/CWLocalFolder.h>
+#import <Pantomime/CWLocalStore.h>
+#import <Pantomime/CWMessage.h>
+#import <Pantomime/CWPOP3Folder.h>
+#import <Pantomime/CWPOP3Store.h>
+#import <Pantomime/CWPOP3CacheManager.h>
+#import <Pantomime/CWTCPConnection.h>
+#import <Pantomime/CWURLName.h>
+#import <Pantomime/CWVirtualFolder.h>
+#import <Pantomime/NSData+Extensions.h>
+#import <Pantomime/NSString+Extensions.h>
 
 #define UPDATE_STATUS_LABEL(format, args...) \
   [label setStringValue: [NSString stringWithFormat: format, ##args]]; \
@@ -1891,7 +1890,12 @@
       [outlineView setAllowsColumnReordering: NO];
       [outlineView setAllowsEmptySelection: YES];
       [outlineView setAllowsMultipleSelection: YES];
-      [outlineView setAutoresizesAllColumnsToFit: YES];
+      /* Available on 10.4 or later */
+      if ([outlineView respondsToSelector:@selector(setColumnAutoresizingStyle:)])
+        [outlineView setColumnAutoresizingStyle: NSTableViewUniformColumnAutoresizingStyle];
+    else
+        [outlineView setAutoresizesAllColumnsToFit: YES];
+    
       [outlineView sizeLastColumnToFit];
 #ifdef GNUSTEP
       [outlineView setIndentationPerLevel: 5];
@@ -2310,7 +2314,12 @@
   [dataView setAllowsEmptySelection: YES];
   [dataView setAllowsMultipleSelection: YES];
   [dataView setIntercellSpacing: NSZeroSize];
-  [dataView setAutoresizesAllColumnsToFit: YES];
+
+  /* Available on 10.4 or later */
+  if ([dataView respondsToSelector:@selector(setColumnAutoresizingStyle:)])
+    [dataView setColumnAutoresizingStyle: NSTableViewUniformColumnAutoresizingStyle];
+  else
+    [dataView setAutoresizesAllColumnsToFit: YES];
   [dataView sizeLastColumnToFit];
 
   [dataView setDataSource: self]; 
