@@ -1,9 +1,11 @@
 /*
 **  NSAttributedString+Extensions.m
 **
-**  Copyright (c) 2004-2007
+**  Copyright (c) 2004-2007 Ludovic Marcotte
+**  Copyright (C) 2015-2017 Riccardo Mottola
 **
 **  Author: Ludovic Marcotte <ludovic@Sophos.ca>
+*+          Riccardo Mottola
 **
 **  This program is free software; you can redistribute it and/or modify
 **  it under the terms of the GNU General Public License as published by
@@ -15,38 +17,37 @@
 **  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 **  GNU General Public License for more details.
 **
-**  You should have received a copy of the GNU General Public License
-**  along with this program; if not, write to the Free Software
-**  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+** You should have received a copy of the GNU General Public License
+** along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include "NSAttributedString+Extensions.h"
+#import "NSAttributedString+Extensions.h"
 
-#include "Constants.h"
-#include "ExtendedTextAttachmentCell.h"
-#include "FilterManager.h"
-#include "GNUMail.h"
-#include "MailHeaderCell.h"
-#include "MailWindowController.h"
-#include "MimeType.h"
-#include "MimeTypeManager.h"
-#include "NSAttributedString+TextEnriched.h"
-#include "NSColor+Extensions.h"
-#include "NSFont+Extensions.h"
-#include "NSUserDefaults+Extensions.h"
-#include "Task.h"
-#include "TaskManager.h"
-#include "ThreadArcsCell.h"
-#include "Utilities.h"
+#import "Constants.h"
+#import "ExtendedTextAttachmentCell.h"
+#import "FilterManager.h"
+#import "GNUMail.h"
+#import "MailHeaderCell.h"
+#import "MailWindowController.h"
+#import "MimeType.h"
+#import "MimeTypeManager.h"
+#import "NSAttributedString+TextEnriched.h"
+#import "NSColor+Extensions.h"
+#import "NSFont+Extensions.h"
+#import "NSUserDefaults+Extensions.h"
+#import "Task.h"
+#import "TaskManager.h"
+#import "ThreadArcsCell.h"
+#import "Utilities.h"
 
-#include <Pantomime/CWFolder.h>
-#include <Pantomime/CWInternetAddress.h>
-#include <Pantomime/CWMessage.h>
-#include <Pantomime/CWMIMEMultipart.h>
-#include <Pantomime/CWMIMEUtility.h>
-#include <Pantomime/CWPart.h>
-#include <Pantomime/NSData+Extensions.h>
-#include <Pantomime/NSString+Extensions.h>
+#import <Pantomime/CWFolder.h>
+#import <Pantomime/CWInternetAddress.h>
+#import <Pantomime/CWMessage.h>
+#import <Pantomime/CWMIMEMultipart.h>
+#import <Pantomime/CWMIMEUtility.h>
+#import <Pantomime/CWPart.h>
+#import <Pantomime/NSData+Extensions.h>
+#import <Pantomime/NSString+Extensions.h>
 
 #define APPEND_HEADER(name, value) ({ \
   [maStr appendAttributedString: [NSAttributedString attributedStringWithString: [NSString stringWithFormat: @"%@: ", _(name)] \
@@ -60,9 +61,9 @@
 //
 //
 //
-static inline int levelFromString(NSString *theString, int start, int end)
+static inline NSUInteger levelFromString(NSString *theString, NSUInteger start, NSUInteger end)
 {
-  int i, level;
+  NSUInteger i, level;
   unichar c;
   
   for (i = start,level = 0; i < end; i++)
@@ -101,9 +102,6 @@ static inline int levelFromString(NSString *theString, int start, int end)
   maStr = [[NSMutableAttributedString alloc] init];
   aData = ([[thePart content] isKindOfClass: [CWMessage class]] ? (id)[(CWMessage *)[thePart content] rawSource] : (id)[thePart content]);
   aFileWrapper = [[NSFileWrapper alloc] initRegularFileWithContents: aData];
-  
-  //NSLog(@"Content-Type = |%@|", [thePart contentType]);
-  // NSLog(@"data from attachmnet part = |%@|", [aData asciiString]);
 
   if (![thePart filename])
     {
@@ -147,10 +145,12 @@ static inline int levelFromString(NSString *theString, int start, int end)
   [aTextAttachment setAttachmentCell: cell];
   
   // Cocoa bug
-#ifdef MACOSX
-  [cell setAttachment: aTextAttachment];
-  [cell setImage: [aFileWrapper icon]];
+  // FIXME RM: 2015-05-22, setting the image cell is needed on GNUstep too
+#if defined(__APPLE__)
+  [cell setAttachment: aTextAttachment]; // needed on Mac or filename will be missing whn trying to save
 #endif
+  [cell setImage: [aFileWrapper icon]];
+  
   RELEASE(cell);
   RELEASE(aFileWrapper);
   
@@ -330,8 +330,9 @@ static inline int levelFromString(NSString *theString, int start, int end)
 	      // Cocoa bug
 #ifdef MACOSX
 	      [cell setAttachment: aTextAttachment];
-	      [cell setImage: [aFileWrapper icon]];
 #endif
+	      [cell setImage: [aFileWrapper icon]];
+
 	      RELEASE(cell);
 	      RELEASE(aFileWrapper);
 	      
@@ -616,18 +617,9 @@ static inline int levelFromString(NSString *theString, int start, int end)
 	  [aTextAttachment setAttachmentCell: theThreadArcsCell];
 	  [aMutableAttributedString appendAttributedString: [NSMutableAttributedString attributedStringWithAttachment: aTextAttachment]];
 	  RELEASE(aTextAttachment);
-#ifndef MACOSX
-	  [aMutableAttributedString appendAttributedString: [NSAttributedString attributedStringWithString: @"\n"
-										attributes: nil]];
-#endif
-	}
-#ifdef MACOSX
+}
       [aMutableAttributedString appendAttributedString: [NSAttributedString attributedStringWithString: @"\n\n"
 									    attributes: nil]];
-#else
-      [aMutableAttributedString appendAttributedString: [NSAttributedString attributedStringWithString: @"\n"
-									    attributes: nil]];
-#endif
     }
   else
     {
@@ -905,15 +897,15 @@ static inline int levelFromString(NSString *theString, int start, int end)
 {
   if (!theAttributes)
     {
-      NSMutableDictionary *aMutableAttributedString;
+      NSAttributedString *aAttributedString;
       NSMutableDictionary *attributes;
 
       attributes = [[NSMutableDictionary alloc] init];
       [attributes setObject: [NSFont systemFontOfSize: 0] forKey: NSFontAttributeName];
-      aMutableAttributedString = [[self alloc] initWithString: theString   attributes: attributes];
+      aAttributedString = [[self alloc] initWithString: theString   attributes: attributes];
       RELEASE(attributes);
       
-      return AUTORELEASE(aMutableAttributedString);
+      return AUTORELEASE(aAttributedString);
     }
   
   
@@ -1115,11 +1107,13 @@ static inline int levelFromString(NSString *theString, int start, int end)
       NSDictionary *attributes;
       NSString *aString;
  
-      int i, j, len, level;
+      NSUInteger i, j;
+      NSUInteger level;
+      NSUInteger len;
      
       aString = [self string];
       len = [aString length];
-      i = j = level = 0;
+      i = j = 0;
       
       for (; i < len; i++)
 	{
