@@ -1,9 +1,11 @@
 /*
 **  TaskManager.m
 **
-**  Copyright (c) 2002-2007
+**  Copyright (c) 2002-2007 Ludovic Marcotte
+**  Copyright (C) 2015-2016 Riccardo Mottola
 **
 **  Author: Ludovic Marcotte <ludovic@Sophos.ca>
+**          Riccardo Mottola <rm@gnu.org>
 **
 **  This program is free software; you can redistribute it and/or modify
 **  it under the terms of the GNU General Public License as published by
@@ -15,9 +17,8 @@
 **  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 **  GNU General Public License for more details.
 **
-**  You should have received a copy of the GNU General Public License
-**  along with this program; if not, write to the Free Software
-**  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+** You should have received a copy of the GNU General Public License
+** along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
 #include "TaskManager.h"
@@ -57,6 +58,7 @@
 #include <Pantomime/CWIMAPFolder.h>
 #include <Pantomime/CWLocalFolder.h>
 #include <Pantomime/CWLocalFolder+mbox.h>
+#include <Pantomime/CWLocalStore.h>
 #include <Pantomime/CWMessage.h>
 #include <Pantomime/CWPOP3CacheManager.h>
 #include <Pantomime/CWPOP3Folder.h>
@@ -300,21 +302,19 @@ static Class CWSMTP_class;
 //
 - (void) removeTask: (Task *) theTask
 {
-  NSInteger i;
+  NSUInteger i;
   
   i = [_tasks indexOfObject: theTask];
 
   if (i != NSNotFound)
     {
       [_tasks removeObjectAtIndex: i];
-#ifdef MACOSX
       // We must do this check in case the console wasn't shown, the progress indicator
       // wouldn't exist.
       if (i < [[[ConsoleWindowController singleInstance] progressIndicators] count])
 	{
 	  [[[[ConsoleWindowController singleInstance] progressIndicators] objectAtIndex: i] removeFromSuperview];
 	}
-#endif
       [[ConsoleWindowController singleInstance] reload];
     }
 }
