@@ -1,9 +1,11 @@
 /*
 **  Utilities.m
 **
-**  Copyright (c) 2001-2007
+**  Copyright (c) 2001-2007 Ludovic Marcotte
+**  Copyright (C) 2015-2017 Riccardo Mottola
 **
 **  Author: Ludovic Marcotte <ludovic@Sophos.ca>
+**          Riccardo Mottola <rm@gnu.org>
 **
 **  This program is free software; you can redistribute it and/or modify
 **  it under the terms of the GNU General Public License as published by
@@ -15,48 +17,48 @@
 **  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 **  GNU General Public License for more details.
 **
-**  You should have received a copy of the GNU General Public License
-**  along with this program; if not, write to the Free Software
-**  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+** You should have received a copy of the GNU General Public License
+** along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include "Utilities.h"
+#import "Utilities.h"
 
-#include "EditWindowController.h"
-#include "ExtendedMenuItem.h"
-#include "ExtendedTextView.h"
-#include "FolderNode.h"
-#include "FolderNodePopUpItem.h"
-#include "GNUMail.h"
-#include "GNUMailBundle.h"
-#include "Constants.h"
-#include "MailboxManagerController.h"
-#include "MailHeaderCell.h"
-#include "MailWindowController.h"
-#include "MessageViewWindowController.h"
-#include "MimeType.h"
-#include "MimeTypeManager.h"
-#include "NSAttributedString+Extensions.h"
-#include "NSFont+Extensions.h"
-#include "NSUserDefaults+Extensions.h"
-#include "PasswordPanelController.h"
-#include "Task.h"
-#include "TaskManager.h"
+#import "EditWindowController.h"
+#import "ExtendedMenuItem.h"
+#import "ExtendedTextView.h"
+#import "FolderNode.h"
+#import "FolderNodePopUpItem.h"
+#import "GNUMail.h"
+#import "GNUMailBundle.h"
+#import "Constants.h"
+#import "MailboxManagerController.h"
+#import "MailHeaderCell.h"
+#import "MailWindowController.h"
+#import "MessageViewWindowController.h"
+#import "MimeType.h"
+#import "MimeTypeManager.h"
+#import "NSAttributedString+Extensions.h"
+#import "NSFont+Extensions.h"
+#import "NSUserDefaults+Extensions.h"
+#import "PasswordPanelController.h"
+#import "Task.h"
+#import "TaskManager.h"
 
-#include <Pantomime/CWFlags.h>
-#include <Pantomime/CWFolder.h>
-#include <Pantomime/CWIMAPFolder.h>
-#include <Pantomime/CWIMAPStore.h>
-#include <Pantomime/CWInternetAddress.h>
-#include <Pantomime/CWLocalFolder.h>
-#include <Pantomime/CWLocalStore.h>
-#include <Pantomime/CWMessage.h>
-#include <Pantomime/CWPart.h>
-#include <Pantomime/CWStore.h>
-#include <Pantomime/CWURLName.h>
-#include <Pantomime/NSData+Extensions.h>
-#include <Pantomime/NSFileManager+Extensions.h>
-#include <Pantomime/NSString+Extensions.h>
+#import <Pantomime/CWFlags.h>
+#import <Pantomime/CWFolder.h>
+#import <Pantomime/CWIMAPFolder.h>
+#import <Pantomime/CWIMAPStore.h>
+#import <Pantomime/CWIMAPMessage.h>
+#import <Pantomime/CWInternetAddress.h>
+#import <Pantomime/CWLocalFolder.h>
+#import <Pantomime/CWLocalStore.h>
+#import <Pantomime/CWMessage.h>
+#import <Pantomime/CWPart.h>
+#import <Pantomime/CWStore.h>
+#import <Pantomime/CWURLName.h>
+#import <Pantomime/NSData+Extensions.h>
+#import <Pantomime/NSFileManager+Extensions.h>
+#import <Pantomime/NSString+Extensions.h>
 
 #include <limits.h>
 
@@ -108,7 +110,7 @@ static NSMutableDictionary *passwordCache = nil;
   NSMutableData *encryptedPassword;
   NSMutableString *key;
   NSString *result;
-  int i;
+  NSUInteger i;
   unichar p, k, e;
 
   // The length of the key must be greater (or equal) than
@@ -151,7 +153,7 @@ static NSMutableDictionary *passwordCache = nil;
   NSData *dec;
   unsigned char *decryptedPassword;
   NSString *result;
-  int i;
+  NSUInteger i;
   unichar p, k, d;
 
   if (thePassword == nil || theKey == nil)
@@ -211,7 +213,7 @@ static NSMutableDictionary *passwordCache = nil;
   NSDictionary *allAccounts;
   NSArray *allKeys;
  
-  int i, index;
+  NSUInteger i, index;
   
   allAccounts = [Utilities allEnabledAccounts];
   allKeys = [[allAccounts allKeys] sortedArrayUsingSelector: @selector(caseInsensitiveCompare:)];
@@ -336,7 +338,7 @@ static NSMutableDictionary *passwordCache = nil;
   NSArray *allKeys, *allRecipients;
   NSString *theAccountAddress;
   NSDictionary *theAccount;
-  int i, j;
+  NSUInteger i, j;
   
   // We get all the message recipients
   allRecipients = [theMessage recipients];
@@ -469,7 +471,7 @@ static NSMutableDictionary *passwordCache = nil;
   if ([[NSUserDefaults standardUserDefaults] objectForKey: @"ACCOUNTS"])
     {
       NSArray *allKeys;
-      int i;
+      NSUInteger i;
 
       aMutableDictionary = [[NSMutableDictionary alloc] initWithDictionary: [[NSUserDefaults standardUserDefaults] 
 									      objectForKey: @"ACCOUNTS"]];
@@ -500,7 +502,7 @@ static NSMutableDictionary *passwordCache = nil;
   NSDictionary *allAccounts;
   NSArray *allKeys;
   
-  int i;
+  NSUInteger i;
   
   allAccounts = [Utilities allEnabledAccounts];
   allKeys = [allAccounts allKeys];
@@ -533,7 +535,7 @@ static NSMutableDictionary *passwordCache = nil;
     {
       CWFolder *aFolder;
       id aWindow;
-      int i;
+      NSUInteger i;
       
       for (i = 0; i < [allWindows count]; i++)
 	{
@@ -566,7 +568,7 @@ static NSMutableDictionary *passwordCache = nil;
 {
   NSString *aName, *aString;
   FolderNode *root;
-  int i;
+  NSInteger i;
  
   root = [[FolderNode alloc] init];
   [root setParent: nil];
@@ -584,7 +586,7 @@ static NSMutableDictionary *passwordCache = nil;
       if (i >= 0)
 	{ 
 	  FolderNode *parent;
-	  int mark;
+	  NSInteger mark;
 	  
 	  parent = root;
 	  mark = 0;
@@ -752,7 +754,7 @@ static NSMutableDictionary *passwordCache = nil;
 				separator: (unsigned char) theSeparator
 {
   NSString *aString;
-  int i;
+  NSInteger i;
   
   if (!theSeparator)
     {
@@ -1867,10 +1869,7 @@ static NSMutableDictionary *passwordCache = nil;
   NSFileWrapper *filewrapper;
   MimeType *aMimeType;
   NSString *aString;
-
-#ifdef MACOSX
   NSWindow *aWindow;
-#endif  
 
   // If it's our header cell, we immediately return
   if ([attachmentCell isKindOfClass: [MailHeaderCell class]])
@@ -1893,7 +1892,6 @@ static NSMutableDictionary *passwordCache = nil;
       [aSavePanel setAccessoryView: nil];
       [aSavePanel setRequiredFileType: @""];
       
-#ifdef MACOSX
       if ([sender respondsToSelector: @selector(window)])
 	{
 	  aWindow = [sender window];
@@ -1909,12 +1907,6 @@ static NSMutableDictionary *passwordCache = nil;
 		  modalDelegate: self 
 		  didEndSelector: @selector(_savePanelDidEnd: returnCode: contextInfo:) 
 		  contextInfo: filewrapper];
-#else
-      [self _savePanelDidEnd: aSavePanel 
-	    returnCode: [aSavePanel runModalForDirectory: [GNUMail currentWorkingPath]
-				    file: [filewrapper preferredFilename]]
-	    contextInfo: filewrapper];
-#endif
     }
   else if ([aMimeType action] == OPEN_WITH_WORKSPACE)
     {
@@ -2185,3 +2177,23 @@ NSString *GNUMailVersion()
   return [[[NSBundle mainBundle] infoDictionary] objectForKey: @"ApplicationRelease"];
 #endif
 }
+
+//
+//
+//
+NSString *GNUMailBaseURL()
+{
+  return @"http://gnustep-nonfsf.nongnu.org/gnumail/";
+}
+
+//
+//
+//
+NSString *GNUMailCopyrightInfo()
+{
+#ifdef MACOSX
+  return [[[NSBundle mainBundle] infoDictionary] objectForKey: @"NSHumanReadableCopyright"]; 
+#else
+  return [[[NSBundle mainBundle] infoDictionary] objectForKey: @"Copyright"];
+#endif
+}
\ No newline at end of file
